@@ -1,5 +1,5 @@
 /*
-* $Header: /home/t-ishii/repository/pgpool/pool_stream.c,v 1.8 2003/07/20 14:44:37 t-ishii Exp $
+* $Header: /home/t-ishii/repository/pgpool/pool_stream.c,v 1.9 2003/08/09 02:27:17 t-ishii Exp $
 *
 * pgpool: a language independent connection pool server for PostgreSQL 
 * written by Tatsuo Ishii
@@ -341,7 +341,7 @@ char *pool_read_string(POOL_CONNECTION *cp, int *len, int line)
 		if (strlength < readlen)
 		{
 			/* save pending data */
-			cp->len = readlen - (readp+strlength);
+			cp->len = readlen - strlength;
 
 			/* pending buffer is enough? */
 			if (cp->len > cp->bufsz)
